@@ -5,7 +5,7 @@ The Estimators module contains a variety of statistical estimators that can be a
 
 # TODO: Consider suggestions at https://stackoverflow.com/questions/35673895/type-hinting-annotation-pep-484-for-numpy-ndarray
 # TODO: Ensure code follows style guide: https://numpydoc.readthedocs.io/en/latest/format.html
-import multiprocessing
+import os
 
 from numba import jit
 import numpy as np
@@ -14,7 +14,7 @@ from scipy.stats import rankdata
 import tqdm
 
 
-def kendall_tau(X: np.ndarray, method='A', n_jobs=multiprocessing.cpu_count()) -> np.float64:
+def kendall_tau(X: np.ndarray, method='A', n_jobs=os.cpu_count()) -> np.float64:
     '''
     Multivariate Kendall's tau.
 
@@ -77,7 +77,7 @@ def kendall_tau(X: np.ndarray, method='A', n_jobs=multiprocessing.cpu_count()) -
         return result
 
 
-def grade_entropy(X: np.ndarray, n_jobs=multiprocessing.cpu_count()) -> np.float64:
+def grade_entropy(X: np.ndarray, n_jobs=os.cpu_count()) -> np.float64:
     '''
     Computes grade entropy for a strict product order
     on the row space points.
@@ -718,3 +718,4 @@ def weak_inner_correlation():
     .. [1] https://arxiv.org/pdf/1904.09542.pdf
     '''
     raise NotImplementedError
+
