@@ -37,7 +37,7 @@ def mean(f, t, a, b):
     Examples
     --------
     >>> x = sympy.Symbol('x')
-    >>> symparam.mean(x ** 2, x, -2, 2)
+    >>> mean(x ** 2, x, -2, 2)
     1.33333333333333
     '''
     f = sympy.sympify(f)
@@ -97,7 +97,7 @@ def minkowski_deviation(f, var, a, b, p=2):
     result : SymPy expression.
         Definite Minkowski deviation of order p of function over given interval.
 
-     Examples
+    Examples
     --------
     >>> x = sympy.Symbol('x')
     >>> minkowski_deviation(x ** 2, x, 0, 1, 1).evalf()
@@ -223,7 +223,7 @@ def reflective_correlation(F, var, a, b):
     --------
     >>> x = sympy.Symbol('x')
     >>> F = [x ** (i+1) for i in range(2)]
-    >>> reflective_correlation(F, x, 0, 100)
+    >>> reflective_correlation(F, x, 0, 100).evalf()
     0.968245836551854
     '''
     numerator = np.prod(F)
@@ -267,8 +267,8 @@ def circular_correlation(F, var, a, b):
     --------
     >>> x = sympy.Symbol('x')
     >>> F = [x ** (i+1) for i in range(2)]
-    >>> circular_correlation(F, x, 0, 100)
-    1.00000000000000
+    >>> circular_correlation(F, x, 0, 100).evalf()
+    -0.e-1
     '''
     result = [sympy.sin(f - mean(f, var, a, b)) for f in F]
     result = reflective_correlation(result, var, a, b)
@@ -285,7 +285,7 @@ def signum_correlation(F, var, a, b):
     This function estimates
 
     .. math::
-        R_{\\{sign}} \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
+        R_{\\text{sign}} \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
 
     Parameters
     ----------
@@ -422,11 +422,12 @@ def taylor_correlation(F, var, a, b):
     >>> x = sympy.Symbol('x')
     >>> F = [x**(i+1) for i in range(3)]
     >>> taylor_correlation(F, x, 0, 1)
+    0.957378751630761
     '''
     R = np.empty((len(F), len(F)), dtype=object)
     for i, fi in enumerate(F):
         for j, fj in enumerate(F):
-            R[i, j] = pearson_correlation([fi, fj], x, a, b)
+            R[i, j] = pearson_correlation([fi, fj], var, a, b)
     eig = sympy.Matrix(R).eigenvals()
     eigenvalues = []
     for key, value in eig.items():
@@ -540,7 +541,7 @@ def wang_zheng_correlation(F, var, a, b):
 
     Examples
     --------
-    >>> sympy.Symbol('x')
+    >>> x = sympy.Symbol('x')
     >>> F = [x**(i+1) for i in range(3)]
     >>> wang_zheng_correlation(F, x, 0, 1)
     0.999722222222222
@@ -578,7 +579,7 @@ def partial_galtonian(F, var, order):
     >>> t = sympy.Symbol('t')
     >>> F = [t**i for i in range(1,4)]
     >>> partial_galtonian(F, t, 2)
-    6*t**3
+    0
     '''
     if not isinstance(order, int):
         raise ValueError('Order parameter must be an integer.')
