@@ -19,7 +19,7 @@ def loss(X):
     for size in range(2, X.shape[1]+1):
         for comb in combinations(range(X.shape[1]), size):
             result += pearson_correlation(X[:,comb])**2
-    return -result
+    return result
 
 x = data_dict['data'].to_numpy()[:,:-1]
 x = tf.constant(x, dtype=tf.float64)
@@ -42,6 +42,7 @@ model.tau = tf.constant(best_params, dtype=tf.float64)
 
 df2 = pd.DataFrame(model(x).numpy())
 df2['species'] = y
+df2 = df2.rename(columns={i:f'Rot({j})' for i,j in zip(range(5), df1.columns)})
 
 sns.pairplot(df1, hue='species')
 sns.pairplot(df2, hue='species')
