@@ -4,12 +4,31 @@ import numpy as np
 tf.keras.backend.set_floatx('float64')
 
 class HypersphericalRotation(tf.keras.Model):
+    '''
+    Trainable hyperspherical rotation of a data set.
+
+    
+    '''
 
     def __init__(self, units=1, input_dim=1):
         super().__init__()
 
     #Consider using @property
     def set_angles(self, x):
+        '''
+        Computes hyperspherical angles of data points and sets a trainable
+        angle in phase space.
+
+        Parameters
+        ----------
+        x : tf.tensor[tf.float64]
+            m x n data matrix
+
+        Returns
+        -------
+        theta : tf.tensor
+            Hyperspherical angles of data points.
+        '''
         self.tau = self.add_weight(shape=(x.shape[1]-1,), initializer="uniform", trainable=True)
         def angle(x):
             theta = []
@@ -25,7 +44,7 @@ class HypersphericalRotation(tf.keras.Model):
                     else:
                         theta.append(2 * np.pi - tf.math.acos(x[j] / tf.linalg.norm(x[j:])).numpy())
             return tf.constant(theta, dtype=tf.float64)
-        self.theta = tf.map_fn(angle, x)
+        self.theta = tf.map_fn(angle, x) # Test if this line is still needed.
         
         
     def call(self, inputs):
@@ -55,11 +74,27 @@ class HypersphericalRotation(tf.keras.Model):
         return tf.concat(y, axis=1)
 
 class SingularValueShift(tf.keras.Model):
+    '''
+    Trainable shift in the singular values of a matrix.
+    '''
     
     def __init__(self):
         super().__init__()
 
     def pretrain(self, inputs):
+        '''
+        Find the singular value decomposition of a
+        matrix.
+
+        Parameters
+        ----------
+        X : tf.tensor
+            m x n data matrix
+
+        Returns
+        -------
+        : None
+        '''
         s,u,v = tf.linalg.svd(inputs)
         self.s = s
         self.u = u
@@ -78,11 +113,27 @@ class SingularValueShift(tf.keras.Model):
         return result
 
 class SVDProjection(tf.keras.Model):
-
+    '''
+    Projects data along singular vectors.
+    '''
     def __init__(self):
         super().__init__()
 
     def fit(self, X):
+        '''
+        Find the singular value decomposition of a matrix,
+        and then project the given data onto the singular
+        vectors.
+
+        Parameters
+        ----------
+        X : tf.tensor
+            m x n data matrix
+
+        Returns
+        -------
+        : None
+        '''
         s, U, V = tf.linalg.svd(X)
         self.s = s
         self.total_s = tf.math.reduce_sum(self.s)
@@ -93,6 +144,21 @@ class SVDProjection(tf.keras.Model):
         self.scores = tf.matmul(U, self.S)
 
     def call(self, X):
+        '''
+        Project a data matrix along singular vectors. The
+        data need not be the same as used to find the singular
+        value decomposition in the first place.
+
+        Parameters
+        ----------
+        X : tf.tensor
+            m x n data matrix
+
+        Returns
+        -------
+         : tf.tensor
+            Projected data.
+        '''
         if hasattr(self, 'V'):
             return tf.matmul(X, self.V)
         else:
